@@ -69,7 +69,7 @@ public:
 
     static PolicyAgent *instance();
 
-    virtual ~PolicyAgent();
+    ~PolicyAgent() override;
 
     /**
      * This function performs a policy check on given policies, and returns a set of unsatisfiable policies,
@@ -105,7 +105,7 @@ private Q_SLOTS:
     void onActiveSessionChanged(const QString &activeSession);
 
 private:
-    explicit PolicyAgent(QObject* parent = 0);
+    explicit PolicyAgent(QObject* parent = nullptr);
 
     void init();
     void startSessionInterruption();
